@@ -28,7 +28,6 @@ class NODE_OT_GLTF_SETTINGS(bpy.types.Operator):
             space is not None
             and space.type == "NODE_EDITOR"
             and context.object and context.object.active_material
-            and context.object.active_material.use_nodes is True
             and bpy.context.preferences.addons['io_scene_gltf2'].preferences.settings_node_ui is True
         )
 
@@ -60,12 +59,7 @@ class gltf2_KHR_materials_variants_variant(bpy.types.PropertyGroup):
 
 class SCENE_UL_gltf2_variants(bpy.types.UIList):
     def draw_item(self, context, layout, data, item, icon, active_data, active_propname, index):
-
-        if self.layout_type in {'DEFAULT', 'COMPACT'}:
-            layout.prop(item, "name", text="", emboss=False)
-
-        elif self.layout_type in {'GRID'}:
-            layout.alignment = 'CENTER'
+        layout.prop(item, "name", text="", emboss=False)
 
 
 class SCENE_PT_gltf2_variants(bpy.types.Panel):
@@ -75,14 +69,14 @@ class SCENE_PT_gltf2_variants(bpy.types.Panel):
     bl_category = "glTF Variants"
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         return bpy.context.preferences.addons['io_scene_gltf2'].preferences.KHR_materials_variants_ui is True
 
     def draw(self, context):
         layout = self.layout
         row = layout.row()
 
-        if bpy.data.scenes[0].get('gltf2_KHR_materials_variants_variants') and len(
+        if bpy.data.scenes[0].gltf2_KHR_materials_variants_variants and len(
                 bpy.data.scenes[0].gltf2_KHR_materials_variants_variants) > 0:
 
             row.template_list(
@@ -115,7 +109,7 @@ class SCENE_OT_gltf2_variant_add(bpy.types.Operator):
     bl_options = {'REGISTER'}
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         return True
 
     def execute(self, context):
@@ -133,7 +127,7 @@ class SCENE_OT_gltf2_variant_remove(bpy.types.Operator):
     bl_options = {'REGISTER'}
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         return len(bpy.data.scenes[0].gltf2_KHR_materials_variants_variants) > 0
 
     def execute(self, context):
@@ -172,7 +166,7 @@ class SCENE_OT_gltf2_display_variant(bpy.types.Operator):
     bl_options = {'REGISTER'}
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         return len(bpy.data.scenes[0].gltf2_KHR_materials_variants_variants) > 0
 
     def execute(self, context):
@@ -200,7 +194,7 @@ class SCENE_OT_gltf2_assign_to_variant(bpy.types.Operator):
     bl_options = {'REGISTER'}
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         return len(bpy.data.scenes[0].gltf2_KHR_materials_variants_variants) > 0 \
             and bpy.context.object and bpy.context.object.type == "MESH"
 
@@ -245,7 +239,7 @@ class SCENE_OT_gltf2_reset_to_original(bpy.types.Operator):
     bl_options = {'REGISTER'}
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         return bpy.context.object and bpy.context.object.type == "MESH" and len(
             context.object.data.gltf2_variant_default_materials) > 0
 
@@ -272,7 +266,7 @@ class SCENE_OT_gltf2_assign_as_original(bpy.types.Operator):
     bl_options = {'REGISTER'}
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         return bpy.context.object and bpy.context.object.type == "MESH"
 
     def execute(self, context):
@@ -320,12 +314,8 @@ class MESH_UL_gltf2_mesh_variants(bpy.types.UIList):
 
         vari = item.variant
         layout.context_pointer_set("id", vari)
-
-        if self.layout_type in {'DEFAULT', 'COMPACT'}:
-            layout.prop(bpy.data.scenes[0].gltf2_KHR_materials_variants_variants[vari.variant_idx],
-                        "name", text="", emboss=False)
-        elif self.layout_type in {'GRID'}:
-            layout.alignment = 'CENTER'
+        layout.prop(bpy.data.scenes[0].gltf2_KHR_materials_variants_variants[vari.variant_idx],
+                    "name", text="", emboss=False)
 
 
 class MESH_PT_gltf2_mesh_variants(bpy.types.Panel):
@@ -335,7 +325,7 @@ class MESH_PT_gltf2_mesh_variants(bpy.types.Panel):
     bl_context = "material"
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         if not bpy.context.object:
             return False
         return bpy.context.preferences.addons['io_scene_gltf2'].preferences.KHR_materials_variants_ui is True \
@@ -347,12 +337,11 @@ class MESH_PT_gltf2_mesh_variants(bpy.types.Panel):
         active_material_slots = bpy.context.object.active_material_index
 
         found = False
-        if 'gltf2_variant_mesh_data' in bpy.context.object.data.keys():
-            for idx, prim in enumerate(bpy.context.object.data.gltf2_variant_mesh_data):
-                if prim.material_slot_index == active_material_slots and id(prim.material) == id(
-                        bpy.context.object.material_slots[active_material_slots].material):
-                    found = True
-                    break
+        for idx, prim in enumerate(bpy.context.object.data.gltf2_variant_mesh_data):
+            if prim.material_slot_index == active_material_slots and id(prim.material) == id(
+                    bpy.context.object.material_slots[active_material_slots].material):
+                found = True
+                break
 
         row = layout.row()
         if found is True:
@@ -363,8 +352,7 @@ class MESH_PT_gltf2_mesh_variants(bpy.types.Panel):
             row.operator("scene.gltf2_remove_material_variant", icon="REMOVE", text="")
 
             row = layout.row()
-            if 'gltf2_KHR_materials_variants_variants' in bpy.data.scenes[0].keys() and len(
-                    bpy.data.scenes[0].gltf2_KHR_materials_variants_variants) > 0:
+            if bpy.data.scenes[0].gltf2_KHR_materials_variants_variants:
                 row.prop_search(
                     context.object.data,
                     "gltf2_variant_pointer",
@@ -376,8 +364,7 @@ class MESH_PT_gltf2_mesh_variants(bpy.types.Panel):
             else:
                 row.label(text="Please Create a Variant First")
         else:
-            if 'gltf2_KHR_materials_variants_variants' in bpy.data.scenes[0].keys() and len(
-                    bpy.data.scenes[0].gltf2_KHR_materials_variants_variants) > 0:
+            if bpy.data.scenes[0].gltf2_KHR_materials_variants_variants:
                 row.operator("scene.gltf2_variants_slot_add", text="Add a new Variant Slot")
             else:
                 row.label(text="Please Create a Variant First")
@@ -390,7 +377,7 @@ class SCENE_OT_gltf2_variant_slot_add(bpy.types.Operator):
     bl_options = {'REGISTER'}
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         if not bpy.context.object:
             return False
         return len(bpy.context.object.material_slots) > 0
@@ -424,7 +411,7 @@ class SCENE_OT_gltf2_material_to_variant(bpy.types.Operator):
     bl_options = {'REGISTER'}
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         if not bpy.context.object:
             return False
         return len(bpy.context.object.material_slots) > 0 and context.object.data.gltf2_variant_pointer != ""
@@ -466,7 +453,7 @@ class SCENE_OT_gltf2_remove_material_variant(bpy.types.Operator):
     bl_options = {'REGISTER'}
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         if not bpy.context.object:
             return False
         return len(bpy.context.object.material_slots) > 0 and len(bpy.context.object.data.gltf2_variant_mesh_data) > 0
@@ -502,16 +489,11 @@ class gltf2_animation_NLATrackNames(bpy.types.PropertyGroup):
 
 class SCENE_UL_gltf2_animation_track(bpy.types.UIList):
     def draw_item(self, context, layout, data, item, icon, active_data, active_propname, index):
-
-        if self.layout_type in {'DEFAULT', 'COMPACT'}:
-            row = layout.row()
-            icon = 'SOLO_ON' if index == bpy.data.scenes[0].gltf2_animation_applied else 'SOLO_OFF'
-            row.prop(item, "name", text="", emboss=False)
-            op = row.operator("scene.gltf2_animation_apply", text='', icon=icon)
-            op.index = index
-
-        elif self.layout_type in {'GRID'}:
-            layout.alignment = 'CENTER'
+        row = layout.row()
+        icon = 'SOLO_ON' if index == bpy.data.scenes[0].gltf2_animation_applied else 'SOLO_OFF'
+        row.prop(item, "name", text="", emboss=False)
+        op = row.operator("scene.gltf2_animation_apply", text='', icon=icon)
+        op.index = index
 
 
 class SCENE_OT_gltf2_animation_apply(bpy.types.Operator):
@@ -523,7 +505,7 @@ class SCENE_OT_gltf2_animation_apply(bpy.types.Operator):
     index: bpy.props.IntProperty()
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         return True
 
     def execute(self, context):
@@ -586,7 +568,7 @@ class SCENE_PT_gltf2_animation(bpy.types.Panel):
     bl_category = "glTF"
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         return bpy.context.preferences.addons['io_scene_gltf2'].preferences.animation_ui is True
 
     def draw(self, context):
@@ -618,7 +600,7 @@ class SCENE_OT_gltf2_action_filter_refresh(bpy.types.Operator):
     bl_options = {'REGISTER'}
 
     @classmethod
-    def poll(self, context):
+    def poll(cls, context):
         return True
 
     def execute(self, context):
@@ -642,13 +624,8 @@ class SCENE_UL_gltf2_filter_action(bpy.types.UIList):
 
         action = item.action
         layout.context_pointer_set("id", action)
-
-        if self.layout_type in {'DEFAULT', 'COMPACT'}:
-            layout.split().prop(item.action, "name", text="", emboss=False)
-            layout.split().prop(item, "keep", text="", emboss=True)
-
-        elif self.layout_type in {'GRID'}:
-            layout.alignment = 'CENTER'
+        layout.split().prop(item.action, "name", text="", emboss=False)
+        layout.split().prop(item, "keep", text="", emboss=True)
 
 
 def export_panel_animation_action_filter(layout, operator):
